@@ -3,7 +3,7 @@ from __future__ import annotations
 
 import warnings
 from dataclasses import dataclass, field
-from typing import Union
+from typing import Union, Callable
 
 import numpy as np
 import libsbml
@@ -68,7 +68,7 @@ class AlgebraicMixin:
     def add_algebraic_module(
         self,
         module_name: str,
-        function: callable,
+        function: Callable,
         compounds: list[str] = None,
         derived_compounds: list[str] = None,
         modifiers: list[str] = None,
@@ -153,7 +153,7 @@ class AlgebraicMixin:
     def update_algebraic_module(
         self,
         module_name: str,
-        function: callable = None,
+        function: Callable = None,
         compounds: list[str] = None,
         derived_compounds: list[str] = None,
         modifiers: list[str] = None,
