@@ -1,16 +1,19 @@
 """Base model module."""
+from __future__ import annotations
 
-# Standard Library
 import copy as copy
+import warnings
 from abc import ABC, abstractmethod
 from dataclasses import dataclass, field
 from datetime import datetime
+from types import TracebackType
+from typing import Optional
 
-# Third party
 import libsbml as libsbml
 
-# Local code
-from .utils import convert_id_to_sbml
+from .utils import convert_id_to_sbml, warning_on_one_line
+
+warnings.formatwarning = warning_on_one_line
 
 
 @dataclass
@@ -28,7 +31,7 @@ class Model:
 class BaseModel(ABC):
     """Abstract model class."""
 
-    def __init__(self, meta_info=None):
+    def __init__(self, meta_info: dict = None):
         default_meta_info = {
             "sbo": "SBO:0000004",  # modelling framework
             "id": f"modelbase-model-{datetime.now().date().strftime('%Y-%m-%d')}",
@@ -54,6 +57,7 @@ class BaseModel(ABC):
         if meta_info is not None:
             default_meta_info.update(meta_info)
         self.meta_info = {"model": Model(**default_meta_info)}
+        self._ids = set()
 
     def __enter__(self):
         """Enter the context manager.
@@ -65,14 +69,19 @@ class BaseModel(ABC):
         self._copy = self.copy()
         return self.copy()
 
-    def __exit__(self, exception_type, exception_value, exception_traceback):
+    def __exit__(
+        self,
+        exception_type: Optional[BaseException],
+        exception_value: Optional[BaseException],
+        exception_traceback: Optional[TracebackType],
+    ):
         """Exit the context manager.
 
         Restores any changes made to the model structure.
         """
         self.__dict__ = self._copy.__dict__
 
-    def copy(self):
+    def copy(self) -> BaseModel:
         """Create a deepcopy of the model.
 
         Returns
@@ -82,7 +91,31 @@ class BaseModel(ABC):
         """
         return copy.deepcopy(self)
 
-    def update_meta_info(self, component, meta_info):
+    def _check_for_existence(self, *, name: str, check_against: list[str], candidates: list[str]):
+        check_against = set(check_against)
+        check_against.add("time")
+        for i in set(candidates).difference(check_against):
+            warnings.warn(f"Could not find {i} for {name}")
+
+    def _check_and_insert_ids(self, ids: list[str]):
+        for id_ in ids:
+            if id_ in self._ids:
+                warnings.warn(f"Id {id_} already exists in the model. This might lead to variable shading!")
+            self._ids.add(id_)
+
+    def _update_ids(self, ids: dict[str, str]):
+        for k, v in ids.items():
+            self._ids.remove(k)
+            self._ids.add(v)
+
+    def _remove_ids(self, ids: list[str]):
+        for id_ in ids:
+            try:
+                self._ids.remove(id_)
+            except KeyError:
+                warnings.warn("Could not find id. Do you have duplicate ids in the model?")
+
+    def update_meta_info(self, component: str, meta_info: dict):
         """Add meta info for any given model component.
 
         Parameters
@@ -100,7 +133,7 @@ class BaseModel(ABC):
             else:
                 setattr(self.meta_info[component], k1, d)
 
-    def _get_nonzero_meta_info(self, *, component):
+    def _get_nonzero_meta_info(self, *, component: str):
         """Get meta info of a component for all entries that are not None.
 
         Parameters
@@ -119,7 +152,7 @@ class BaseModel(ABC):
     # SBML functions
     ##########################################################################
 
-    def _create_sbml_document(self):
+    def _create_sbml_document(self) -> libsbml.SBMLDocument:
         """Create an sbml document, into which sbml information can be written.
 
         Returns
@@ -135,7 +168,7 @@ class BaseModel(ABC):
         doc.setSBOTerm(self.meta_info["model"].sbo)
         return doc
 
-    def _create_sbml_model(self, *, doc):
+    def _create_sbml_model(self, *, doc: libsbml.SBMLDocument) -> libsbml.Model:
         """Create an sbml model.
 
         Parameters
@@ -156,7 +189,7 @@ class BaseModel(ABC):
         sbml_model_fbc.setStrict(True)
         return sbml_model
 
-    def _create_sbml_units(self, *, sbml_model):
+    def _create_sbml_units(self, *, sbml_model: libsbml.Model):
         """Create sbml units out of the meta_info.
 
         Parameters
@@ -172,7 +205,7 @@ class BaseModel(ABC):
             sbml_unit.setScale(unit["scale"])
             sbml_unit.setMultiplier(unit["multiplier"])
 
-    def _create_sbml_compartments(self, *, sbml_model):
+    def _create_sbml_compartments(self, *, sbml_model: libsbml.Model):
         """Create the compartments for the sbml model.
 
         Since modelbase does not enforce any compartments, so far
@@ -195,7 +228,7 @@ class BaseModel(ABC):
     def _model_to_sbml(self):
         """Define which methods shall be used for sbml export."""
 
-    def write_sbml_model(self, filename=None):
+    def write_sbml_model(self, filename: str = None):
         """Write the model to an sbml file.
 
         Parameters
