@@ -5,6 +5,7 @@ import json as json
 import pickle as pickle
 import warnings
 from dataclasses import dataclass, field
+from typing import Callable
 
 import libsbml
 
@@ -157,7 +158,7 @@ class ParameterMixin:
         for parameter_name in parameter_names:
             self.remove_parameter(parameter_name=parameter_name)
 
-    def add_derived_parameter(self, parameter_name: str, function: callable, parameters: list[str] = None):
+    def add_derived_parameter(self, parameter_name: str, function: Callable, parameters: list[str] = None):
         """Add a derived parameter.
 
         Derived parameters are calculated from other model parameters and dynamically updated
