@@ -4,7 +4,7 @@ from __future__ import annotations
 import warnings
 from collections import defaultdict
 from dataclasses import dataclass, field
-from typing import Union
+from typing import Union, Callable
 
 import libsbml
 
@@ -47,7 +47,7 @@ class RateMixin:
     # Basic rate functions
     ##########################################################################
 
-    def add_function(self, function_name: str, function: callable):
+    def add_function(self, function_name: str, function: Callable):
         if function.__name__ == "<lambda>":
             patch_lambda_function_name(function=function, name=function_name)
 
@@ -57,7 +57,7 @@ class RateMixin:
         for function_name, function in functions.items():
             self.add_function(function_name=function_name, function=function)
 
-    def update_function(self, function_name: str, function: callable):
+    def update_function(self, function_name: str, function: Callable):
         if function.__name__ == "<lambda>":
             patch_lambda_function_name(function=function, name=function_name)
         self.functions[function_name] = function
@@ -76,7 +76,7 @@ class RateMixin:
     def add_rate(
         self,
         rate_name: str,
-        function: callable,
+        function: Callable,
         substrates: list[str] = None,
         products: list[str] = None,
         modifiers: list[str] = None,
@@ -196,7 +196,7 @@ class RateMixin:
     def update_rate(
         self,
         rate_name: str,
-        function: callable = None,
+        function: Callable = None,
         substrates: list[str] = None,
         products: list[str] = None,
         modifiers: list[str] = None,
