@@ -2,8 +2,9 @@
 from __future__ import annotations
 
 import inspect as inspect
-import re as re
+import re
 import subprocess
+from typing import Callable
 
 RE_LAMBDA_FUNC = re.compile(r".*(lambda)(.+?):(.*?)")
 RE_LAMBDA_RATE_FUNC = re.compile(r".*(lambda)(.+?):(.*?),")
@@ -23,7 +24,7 @@ def warning_on_one_line(message: str, category, filename: str, lineno: int, file
 ##########################################################################
 
 
-def get_function_source_code(function: callable) -> str:
+def get_function_source_code(function: Callable) -> str:
     """Get source code of a function."""
     try:
         return inspect.getsource(function)[:-1]  # Remove line break
@@ -31,7 +32,7 @@ def get_function_source_code(function: callable) -> str:
         return function.__source__
 
 
-def patch_lambda_function_name(function: callable, name: str):
+def patch_lambda_function_name(function: Callable, name: str):
     """Add a name to a lambda function."""
     if function.__name__ == "<lambda>":
         function.__name__ = name
@@ -46,7 +47,7 @@ def functionify_lambda(lambda_function_code: str, function_name: str, pattern: r
     return f"def {function_name}({args.strip()}):\n    return {code.strip()}"
 
 
-def get_formatted_function_source_code(function_name: str, function: callable, function_type: str) -> str:
+def get_formatted_function_source_code(function_name: str, function: Callable, function_type: str) -> str:
     """Get source code of a function and format it using black."""
     source = get_function_source_code(function=function)
 
