@@ -4,7 +4,7 @@ from __future__ import annotations
 import itertools as it
 import warnings
 from collections import defaultdict as _defaultdict
-from typing import Union
+from typing import Union, Callable
 
 import libsbml
 import numpy as np
@@ -340,7 +340,7 @@ class LabelModel(Model):
     def add_algebraic_module(
         self,
         module_name: str,
-        function: callable,
+        function: Callable,
         compounds: list[str] = None,
         derived_compounds: list[str] = None,
         modifiers: list[str] = None,
@@ -434,7 +434,7 @@ class LabelModel(Model):
         self,
         *,
         rate_name: str,
-        function: callable,
+        function: Callable,
         stoichiometry: dict[str, float],
         base_substrates: list[str],
         base_products: list[str],
@@ -480,7 +480,7 @@ class LabelModel(Model):
         self,
         *,
         rate_name: str,
-        function: callable,
+        function: Callable,
         labelmap: list[int],
         modifiers: list[str],
         parameters: list[str],
@@ -534,7 +534,7 @@ class LabelModel(Model):
     def add_labelmap_reaction(
         self,
         rate_name: str,
-        function: callable,
+        function: Callable,
         stoichiometry: dict[str, float],
         labelmap: list[int],
         external_labels: Union[int, list[int]] = None,
@@ -644,7 +644,7 @@ class LabelModel(Model):
     def update_labelmap_reaction(
         self,
         rate_name: str,
-        function: callable = None,
+        function: Callable = None,
         stoichiometry: dict[str, int] = None,
         labelmap: list[int] = None,
         modifiers: list[str] = None,
