@@ -1,20 +1,19 @@
 """LinearLabelModel base class."""
+from __future__ import annotations
 
-# Standard Library
 import warnings
+from typing import Union
 
-# Third party
 import libsbml
 import numpy as np
 import pandas as pd
 
-# Local code
 from ...core import BaseModel, CompoundMixin, RateMixin, StoichiometricMixin
 from ...core.ratemixin import Rate
 from ...core.utils import convert_id_to_sbml
 
 
-def relative_label_flux(substrate, v_ss):
+def relative_label_flux(substrate: float, v_ss: float):
     """Calculate relative label flux."""
     return v_ss * substrate
 
@@ -22,7 +21,13 @@ def relative_label_flux(substrate, v_ss):
 class LinearLabelModel(RateMixin, StoichiometricMixin, CompoundMixin, BaseModel):
     """LinearLabelModel."""
 
-    def __init__(self, compounds=None, rate_stoichiometries=None, rates=None, meta_info=None):
+    def __init__(
+        self,
+        compounds: dict = None,
+        rate_stoichiometries: dict = None,
+        rates: dict = None,
+        meta_info: dict = None,
+    ):
         self.isotopomers = {}
         self.base_rates = {}
         BaseModel.__init__(self, meta_info=meta_info)
@@ -32,25 +37,14 @@ class LinearLabelModel(RateMixin, StoichiometricMixin, CompoundMixin, BaseModel)
         self.meta_info["model"].sbo = "SBO:0000062"  # continuous framework
 
     @staticmethod
-    def _generate_isotope_labels(*, base_name, num_labels):
-        """Create binary label string.
-
-        Parameters
-        ----------
-        base_name : str
-        num_labels : int
-
-        Returns
-        -------
-        isotopomers : list(str)
-            Returns a list of all label isotopomers of the compound
-        """
+    def _generate_isotope_labels(*, base_name: str, num_labels: list[str]) -> list[str]:
+        """Returns a list of all label isotopomers of the compound."""
         if num_labels > 0:
             return [f"{base_name}__{i}" for i in range(num_labels)]
         else:
             raise ValueError(f"Compound {base_name} must have labels")
 
-    def add_compound(self, compound, num_labels):
+    def add_compound(self, compound: str, num_labels: int):
         """Add a label-containing compound to the model."""
         if compound in self.isotopomers:
             self.remove_compound(compound=compound)
@@ -58,46 +52,40 @@ class LinearLabelModel(RateMixin, StoichiometricMixin, CompoundMixin, BaseModel)
 
         label_names = self._generate_isotope_labels(base_name=compound, num_labels=num_labels)
         self.isotopomers[compound] = label_names
+        self._check_and_insert_ids([compound])
 
         # Add all labelled compounds
         for isotopomer in label_names:
             super().add_compound(compound=isotopomer)
 
-    def add_compounds(self, compounds):
+    def add_compounds(self, compounds: dict[str, int]):
         """Add multiple label-containing compounds to the model.
 
         Parameters
         ----------
-        compounds : dict(str, int)
-            {compound: num_labels} dictionary
+        compounds
+            {compound_name: num_labels}
         """
         for compound, num_labels in compounds.items():
             self.add_compound(compound=compound, num_labels=num_labels)
 
-    def remove_compound(self, compound):
-        """Remove a compound from the model.
-
-        Parameters
-        ----------
-        compound : str
-        """
+    def remove_compound(self, compound: str):
+        """Remove a compound from the model."""
         isotopomers = self.isotopomers.pop(compound)
         for i in isotopomers:
-            self.compounds.remove(i)
+            super().remove_compound(i)
+        self._remove_ids([compound])
 
-    def add_rate(self, rate_name, base_name, substrate, **meta_info):
+    def add_rate(self, rate_name: str, base_name: str, substrate: str, **meta_info):
         """Add a rate function to the model.
 
-        The Python function will get the function arguments in the following order:
-        [**substrates, **(products if reversible), **modifiers, **parameters.]
-
         Parameters
         ----------
-        rate_name : str
+        rate_name
             Name of the rate function plus suffixes
-        base_name : str
+        base_name
             Name of the rate function
-        substrate: str
+        substrate
             Name of the substrate
         meta_info : dict, optional
             Meta info of the rate. Allowed keys are
@@ -120,18 +108,8 @@ class LinearLabelModel(RateMixin, StoichiometricMixin, CompoundMixin, BaseModel)
         self.meta_info.setdefault("rates", {}).setdefault(rate_name, Rate(**meta_info))
 
     @staticmethod
-    def _unpack_stoichiometries(*, stoichiometries):
-        """Split stoichiometries into substrates and products.
-
-        Parameters
-        ----------
-        stoichiometries : dict(str: int)
-
-        Returns
-        -------
-        substrates : list(str)
-        products : list(str)
-        """
+    def _unpack_stoichiometries(*, stoichiometries: dict[str, int]) -> tuple[list[str], list[str]]:
+        """Split stoichiometries into substrates and products."""
         substrates = []
         products = []
         for k, v in stoichiometries.items():
@@ -142,7 +120,13 @@ class LinearLabelModel(RateMixin, StoichiometricMixin, CompoundMixin, BaseModel)
         return substrates, products
 
     @staticmethod
-    def _add_label_influx_or_efflux(*, rate_name, substrates, products, labelmap):
+    def _add_label_influx_or_efflux(
+        *,
+        rate_name: str,
+        substrates: list[str],
+        products: list[str],
+        labelmap: list[int],
+    ):
         # Label outfluxes
         diff = len(substrates) - len(products)
         for _ in range(diff):
@@ -158,17 +142,15 @@ class LinearLabelModel(RateMixin, StoichiometricMixin, CompoundMixin, BaseModel)
                 substrates.append("EXT")
 
     @staticmethod
-    def _map_substrates_to_labelmap(*, substrates, labelmap):
+    def _map_substrates_to_labelmap(*, substrates: list[str], labelmap: list[int]) -> list[str]:
         return [substrates[i] for i in labelmap]
 
-    def add_reaction(self, rate_name, stoichiometry, labelmap):
+    def add_reaction(self, rate_name: str, stoichiometry: dict[str, int], labelmap: list[int]):
         """Add a reaction to the model.
 
-        Parameters
-        ----------
-        rate_name : str
-        stoichiometry : dict
-        labelmap : iterable(int)
+        Examples
+        --------
+        >>> add_reaction(rate_name="v1", stoichiometry={"x": -1, "y": 1}, labelmap=[0, 1])
         """
         if rate_name in self.base_rates:
             warnings.warn(f"Overwriting reaction {rate_name}")
@@ -195,7 +177,7 @@ class LinearLabelModel(RateMixin, StoichiometricMixin, CompoundMixin, BaseModel)
                 **{"sbml_function": f"{rate_name} * {substrate}"},
             )
 
-    def remove_reaction(self, rate_name):
+    def remove_reaction(self, rate_name: str):
         """Remove a reaction from the model.
 
         Parameters
@@ -205,18 +187,13 @@ class LinearLabelModel(RateMixin, StoichiometricMixin, CompoundMixin, BaseModel)
         for rate in self.base_rates[rate_name]:
             self.remove_rate(rate_name=rate)
             self.remove_rate_stoichiometry(rate_name=rate)
+        del self.base_rates[rate_name]
 
-    def generate_y0(self, initial_labels=None):
+    def generate_y0(
+        self, initial_labels: Union[dict[str, int], dict[str, list[int]]] = None
+    ) -> dict[str, float]:
         """Generate y0 for all isotopomers.
 
-        Parameters
-        ----------
-        initial_labels : dict(str: num)
-
-        Returns
-        -------
-        y0 : dict(str: num)
-
         Examples
         --------
         >>> generate_y0()
@@ -232,42 +209,35 @@ class LinearLabelModel(RateMixin, StoichiometricMixin, CompoundMixin, BaseModel)
                     y0[f"{base_compound}__{pos}"] = 1 / len(label_positions)
         return y0
 
-    def _get_fluxes(self, *, fcd: dict, v_ss: dict, external_label=1):
+    def _get_fluxes(
+        self, *, fcd: dict[str, float], v_ss: dict[str, float], external_label: float = 1.0
+    ) -> dict[str, float]:
         fcd["EXT"] = external_label
-
         fluxes = {}
         for name, rate in self.rates.items():
             fluxes[name] = relative_label_flux(fcd[rate["substrate"]], v_ss[rate["base_name"]])
         return fluxes
 
-    def get_fluxes_dict(self, y, v_ss, external_label=1, t=0):
-        """Calculate the fluxes at time point(s) t.
-
-        Parameters
-        ----------
-        y : Union(dict(str: num), iterable(num))
-        t : Union(num, iterable(num))
-
-        Returns
-        -------
-        fluxes : dict
-        """
+    def get_fluxes_dict(
+        self,
+        y: dict[str, float],
+        v_ss: dict[str, float],
+        external_label: float = 1.0,
+        t: float = 0.0,
+    ) -> dict[str, float]:
+        """Calculate the fluxes at time point(s) t."""
         if not isinstance(y, dict):
             y = dict(zip(self.compounds, y))
         return self._get_fluxes(fcd=y, v_ss=v_ss, external_label=external_label)
 
-    def get_fluxes_array(self, y, v_ss, external_label=1, t=0):
-        """Calculate the fluxes at time point(s) t.
-
-        Parameters
-        ----------
-        y : Union(dict(str: num), iterable(num))
-        t : Union(num, iterable(num))
-
-        Returns
-        -------
-        fluxes : numpy.array
-        """
+    def get_fluxes_array(
+        self,
+        y: dict[str, float],
+        v_ss: dict[str, float],
+        external_label: float = 1.0,
+        t: float = 0.0,
+    ) -> np.ndarray:
+        """Calculate the fluxes at time point(s) t."""
         return np.array(
             [
                 i
@@ -279,7 +249,13 @@ class LinearLabelModel(RateMixin, StoichiometricMixin, CompoundMixin, BaseModel)
             ]
         ).T
 
-    def get_fluxes_df(self, y, v_ss, external_label=1, t=0):
+    def get_fluxes_df(
+        self,
+        y: dict[str, float],
+        v_ss: dict[str, float],
+        external_label: float = 1.0,
+        t: float = 0.0,
+    ) -> pd.DataFrame:
         """Calculate the fluxest.
 
         Parameters
@@ -301,7 +277,7 @@ class LinearLabelModel(RateMixin, StoichiometricMixin, CompoundMixin, BaseModel)
 
     # This can't get keyword-only arguments, as the integrators are calling it with
     # positional arguments
-    def _get_rhs(self, t, y_labels):
+    def _get_rhs(self, t: float, y_labels: list[float]) -> list[float]:
         y_labels = dict(zip(self.compounds, y_labels))
         dxdt = {i: 0 for i in y_labels}
 
@@ -312,22 +288,29 @@ class LinearLabelModel(RateMixin, StoichiometricMixin, CompoundMixin, BaseModel)
                     dxdt[isotomoper] += stoich * fluxes[rate] / self._y_ss[compound]
         return list(dxdt.values())
 
-    def get_right_hand_side(self, y_labels, y_ss, v_ss, external_label=1, t=0):
+    def get_right_hand_side(
+        self,
+        y_labels: dict[str, float],
+        y_ss: dict[str, float],
+        v_ss: dict[str, float],
+        external_label: float = 1.0,
+        t: float = 0.0,
+    ) -> dict[str, float]:
         """Calculate the right hand side of the ODE system.
 
         Parameters
         ----------
-        y_labels : dict
+        y_labels
             Relative concentrations of the label positions
-        y_ss : dict
+        y_ss
             Steady-state concentrations of the base compounds
             obtained from the non-labelled model
-        v_ss : dict
+        v_ss
             Steady-state fluxes of the base reactions
             obtained from the non-labelled model
-        external_label : num
+        external_label
             Relative concentration of an external label pool
-        t : num
+        t
             Time
         """
         self._y_ss = y_ss
@@ -335,13 +318,13 @@ class LinearLabelModel(RateMixin, StoichiometricMixin, CompoundMixin, BaseModel)
         self._external_label = external_label
         if isinstance(y_labels, dict):
             y_labels = [y_labels[i] for i in self.compounds]
-        return dict(zip(self.compounds, self._get_rhs(t=0, y_labels=y_labels)))
+        return dict(zip(self.compounds, self._get_rhs(t=t, y_labels=y_labels)))
 
     ##########################################################################
     # SBML functions
     ##########################################################################
 
-    def _create_sbml_reactions(self, *, sbml_model):
+    def _create_sbml_reactions(self, *, sbml_model: libsbml.Model):
         """Create the reactions for the sbml model.
 
         Parameters
@@ -368,7 +351,7 @@ class LinearLabelModel(RateMixin, StoichiometricMixin, CompoundMixin, BaseModel)
             kinetic_law = rxn.createKineticLaw()
             kinetic_law.setMath(libsbml.parseL3Formula(rate.sbml_function))
 
-    def _model_to_sbml(self):
+    def _model_to_sbml(self) -> libsbml.SBMLDocument:
         """Export model to sbml."""
         doc = self._create_sbml_document()
         sbml_model = self._create_sbml_model(doc=doc)
