@@ -6,7 +6,7 @@ from __future__ import annotations
 
 import subprocess
 import warnings
-from typing import Union, Iterable
+from typing import Union, Iterable, Callable
 
 import libsbml
 import numpy as np
@@ -217,7 +217,7 @@ class Model(
     def add_reaction(
         self,
         rate_name: str,
-        function: callable,
+        function: Callable,
         stoichiometry: dict[str, int],
         modifiers: list[str] = None,
         parameters: list[str] = None,
@@ -274,7 +274,7 @@ class Model(
     def update_reaction(
         self,
         rate_name: str,
-        function: callable = None,
+        function: Callable = None,
         stoichiometry: dict[str, float] = None,
         modifiers: list[str] = None,
         parameters: list[str] = None,
@@ -288,7 +288,7 @@ class Model(
         Parameters
         ----------
         rate_name : str
-        function : callable, optional
+        function : Callable, optional
         stoichiometry : dict, optional
         modifiers: iterable(str), optional
         parameters: iterable(str), optional
