@@ -1,9 +1,14 @@
 """Simulator for LinearLabelModels."""
+from __future__ import annotations
 
-# Standard Library
 import copy
+from typing import Union, Any
+
+import numpy as np
+import pandas as pd
+import matplotlib.pyplot as plt
+
 
-# Local code
 from ...utils.plotting import plot, plot_grid
 from .basesimulator import _BaseSimulator
 
@@ -11,7 +16,7 @@ from .basesimulator import _BaseSimulator
 class _LinearLabelSimulate(_BaseSimulator):
     """Simulator for LinearLabelModels."""
 
-    def __init__(self, model, integrator_name, **kwargs):
+    def __init__(self, model, integrator_name: str, **kwargs):
         super().__init__(model=model, integrator_name=integrator_name, **kwargs)
 
     def _test_run(self):
@@ -29,7 +34,7 @@ class _LinearLabelSimulate(_BaseSimulator):
             t=0,
         )
 
-    def copy(self):
+    def copy(self) -> _LinearLabelSimulate:
         """Return a deepcopy of this class."""
         new = copy.deepcopy(self)
         if new.results is not None:
@@ -44,105 +49,60 @@ class _LinearLabelSimulate(_BaseSimulator):
             )
         return new
 
-    def initialise(self, label_y0, y_ss, v_ss, external_label=1, test_run=True):
-        """Initialise the integrator.
-
-        Parameters
-        ----------
-        y0 : Union(dict(str: num), iterable(num))
-        test_run : bool
-            Whether to perform a test_run to get proper error handling.
-        """
+    def initialise(
+        self,
+        label_y0: dict[str, float],
+        y_ss: dict[str, float],
+        v_ss: dict[str, float],
+        external_label: float = 1.0,
+        test_run: bool = True,
+    ):
         self.model._y_ss = y_ss
         self.model._v_ss = v_ss
         self.model._external_label = external_label
         super().initialise(y0=label_y0, test_run=test_run)
 
-    def get_label_position(self, compound, position):
+    def get_label_position(self, compound: str, position: int) -> np.ndarray:
         """Get relative concentration of a single isotopomer.
 
-        Parameters
-        ----------
-        compound : str
-            name of the base compound
-        position : int
-            position
-
-        Returns
-        -------
-        isotopomer_concentration : numpy.ndarray
-
         Examples
         --------
-        get_label_position(compound="GAP", position=2)
+        >>> get_label_position(compound="GAP", position=2)
         """
         return self.get_results_dict()[self.model.isotopomers[compound][position]]
 
-    def get_label_distribution(self, compound):
+    def get_label_distribution(self, compound: str) -> np.ndarray:
         """Get relative concentrations of all compound isotopomers.
 
-        Parameters
-        ----------
-        compound : str
-            name of the base compound
-
-        Returns
-        -------
-        isotopomer_concentrations : numpy.ndarray
-
         Examples
         --------
-        get_label_position(compound="GAP")
+        >>> get_label_position(compound="GAP")
         """
         compounds = self.model.isotopomers[compound]
         return self.get_results_df().loc[:, compounds].values
 
     def plot_label_distribution(
         self,
-        compound,
-        relative=True,
-        xlabel=None,
-        ylabel=None,
-        title=None,
-        grid=True,
-        tight_layout=True,
-        ax=None,
-        figure_kwargs=None,
-        subplot_kwargs=None,
-        plot_kwargs=None,
-        grid_kwargs=None,
-        legend_kwargs=None,
-        tick_kwargs=None,
-        label_kwargs=None,
-        title_kwargs=None,
-    ):
-        """Plot label distribution of a compound.
-
-        Parameters
-        ----------
-        compound : str
-        relative : bool
-        xlabel : str
-        ylabel : str
-        title : str
-        grid : bool
-        ax : matplotlib.axes
-        figure_kwargs : dict
-        subplot_kwargs : dict
-        plot_kwargs : dict
-        grid_kwargs : dict
-        legend_kwargs : dict
-        tick_kwargs : dict
-        label_kwargs : dict
-        title_kwargs : dict
-
-        Returns
-        -------
-        concentrations : numpy.array
-        """
+        compound: str,
+        relative: bool = True,
+        xlabel: str = None,
+        ylabel: str = None,
+        title: str = None,
+        grid: bool = True,
+        tight_layout: bool = True,
+        ax: plt.Axes = None,
+        figure_kwargs: dict[str, Any] = None,
+        subplot_kwargs: dict[str, Any] = None,
+        plot_kwargs: dict[str, Any] = None,
+        grid_kwargs: dict[str, Any] = None,
+        legend_kwargs: dict[str, Any] = None,
+        tick_kwargs: dict[str, Any] = None,
+        label_kwargs: dict[str, Any] = None,
+        title_kwargs: dict[str, Any] = None,
+    ) -> tuple[plt.Figure, plt.Axes]:
+        """Plot label distribution of a compound."""
         if ylabel is None and relative:
             ylabel = "Relative concentration"
-
         x = self.get_time()
         y = self.get_label_distribution(compound=compound)
         legend = [f"Pos {i}" for i in range(len(self.model.isotopomers[compound]))]
@@ -169,55 +129,33 @@ class _LinearLabelSimulate(_BaseSimulator):
 
     def plot_label_distribution_grid(
         self,
-        compounds,
-        relative=True,
-        ncols=None,
-        sharex=True,
-        sharey=True,
-        xlabels=None,
-        ylabels=None,
+        compounds: list[str],
+        relative: bool = True,
+        ncols: int = None,
+        sharex: bool = True,
+        sharey: bool = True,
+        xlabels: list[str] = None,
+        ylabels: list[str] = None,
         plot_titles=None,
-        figure_title=None,
-        grid=True,
-        tight_layout=True,
-        ax=None,
-        figure_kwargs=None,
-        subplot_kwargs=None,
-        plot_kwargs=None,
-        grid_kwargs=None,
-        legend_kwargs=None,
-        tick_kwargs=None,
-        label_kwargs=None,
-        title_kwargs=None,
-    ):
-        """Plot label distributions of multiple compounds on a grid.
-
-        Parameters
-        ----------
-        compounds : iterable(str)
-        relative : bool
-        ncols : int
-        xlabel : str
-        ylabel : str
-        title : str
-        grid : bool
-        ax : matplotlib.axes
-        figure_kwargs : dict
-        subplot_kwargs : dict
-        plot_kwargs : dict
-        grid_kwargs : dict
-        legend_kwargs : dict
-        tick_kwargs : dict
-        label_kwargs : dict
-        title_kwargs : dict
-
-        Returns
-        -------
-        concentrations : numpy.array
-        """
+        figure_title: str = None,
+        grid: bool = True,
+        tight_layout: bool = True,
+        ax: plt.Axes = None,
+        figure_kwargs: dict[str, Any] = None,
+        subplot_kwargs: dict[str, Any] = None,
+        plot_kwargs: dict[str, Any] = None,
+        grid_kwargs: dict[str, Any] = None,
+        legend_kwargs: dict[str, Any] = None,
+        tick_kwargs: dict[str, Any] = None,
+        label_kwargs: dict[str, Any] = None,
+        title_kwargs: dict[str, Any] = None,
+    ) -> Union[plt.Figure, np.ndarray[plt.Axes]]:
+        """Plot label distributions of multiple compounds on a grid."""
         time = self.get_time()
         plot_groups = [(time, self.get_label_distribution(compound=compound)) for compound in compounds]
-        legend_groups = [[f"Pos {i}" for i in range(len(self.model.isotopomers[compound]))] for compound in compounds]
+        legend_groups = [
+            [f"Pos {i}" for i in range(len(self.model.isotopomers[compound]))] for compound in compounds
+        ]
         if ylabels is None and relative:
             ylabels = "Relative concentration"
         if plot_titles is None:
@@ -247,54 +185,33 @@ class _LinearLabelSimulate(_BaseSimulator):
 
     def plot_all_label_distributions(
         self,
-        relative=True,
-        ncols=None,
-        sharex=True,
-        sharey=True,
-        xlabels=None,
-        ylabels=None,
+        relative: bool = True,
+        ncols: int = None,
+        sharex: bool = True,
+        sharey: bool = True,
+        xlabels: list[str] = None,
+        ylabels: list[str] = None,
         plot_titles=None,
-        figure_title=None,
-        grid=True,
-        tight_layout=True,
-        ax=None,
-        figure_kwargs=None,
-        subplot_kwargs=None,
-        plot_kwargs=None,
-        grid_kwargs=None,
-        legend_kwargs=None,
-        tick_kwargs=None,
-        label_kwargs=None,
-        title_kwargs=None,
-    ):
-        """Plot label distributions of all compounds on a grid.
-
-        Parameters
-        ----------
-        relative : bool
-        ncols : int
-        xlabel : str
-        ylabel : str
-        title : str
-        grid : bool
-        ax : matplotlib.axes
-        figure_kwargs : dict
-        subplot_kwargs : dict
-        plot_kwargs : dict
-        grid_kwargs : dict
-        legend_kwargs : dict
-        tick_kwargs : dict
-        label_kwargs : dict
-        title_kwargs : dict
-
-        Returns
-        -------
-        concentrations : numpy.array
-        """
+        figure_title: str = None,
+        grid: bool = True,
+        tight_layout: bool = True,
+        ax: plt.Axes = None,
+        figure_kwargs: dict[str, Any] = None,
+        subplot_kwargs: dict[str, Any] = None,
+        plot_kwargs: dict[str, Any] = None,
+        grid_kwargs: dict[str, Any] = None,
+        legend_kwargs: dict[str, Any] = None,
+        tick_kwargs: dict[str, Any] = None,
+        label_kwargs: dict[str, Any] = None,
+        title_kwargs: dict[str, Any] = None,
+    ) -> Union[plt.Figure, np.ndarray[plt.Axes]]:
+        """Plot label distributions of all compounds on a grid."""
         time = self.get_time()
         compounds = self.model.isotopomers
         plot_groups = [(time, self.get_label_distribution(compound=compound)) for compound in compounds]
-        legend_groups = [[f"Pos {i}" for i in range(len(self.model.isotopomers[compound]))] for compound in compounds]
+        legend_groups = [
+            [f"Pos {i}" for i in range(len(self.model.isotopomers[compound]))] for compound in compounds
+        ]
         if ylabels is None and relative:
             ylabels = "Relative concentration"
         if plot_titles is None:
