@@ -611,7 +611,7 @@ class _Simulate(_BaseSimulator):
 
     def plot_grid(
         self,
-        compound_groups: list[str],
+        compound_groups: list[list[str]],
         ncols: int = None,
         sharex: bool = True,
         sharey: bool = True,
@@ -632,7 +632,12 @@ class _Simulate(_BaseSimulator):
         label_kwargs: dict[str, Any] = None,
         title_kwargs: dict[str, Any] = None,
     ) -> tuple[plt.Figure, np.ndarray[plt.Axes]]:
-        """Plot simulation results of the compound groups as a grid."""
+        """Plot simulation results of the compound groups as a grid.
+
+        Examples
+        --------
+        >>> plot_grid([["x1", "x2"], ["x3", "x4]])
+        """
         time = self.get_time()
         plot_groups = [
             (
@@ -913,6 +918,67 @@ class _Simulate(_BaseSimulator):
             title_kwargs=title_kwargs,
         )
 
+    def plot_fluxes_grid(
+        self,
+        rate_groups: list[list[str]],
+        ncols: int = None,
+        sharex: bool = True,
+        sharey: bool = True,
+        xlabels: list[str] = None,
+        ylabels: list[str] = None,
+        normalise=None,
+        plot_titles=None,
+        figure_title: str = None,
+        grid: bool = True,
+        tight_layout: bool = True,
+        ax: plt.Axes = None,
+        figure_kwargs: dict[str, Any] = None,
+        subplot_kwargs: dict[str, Any] = None,
+        plot_kwargs: dict[str, Any] = None,
+        grid_kwargs: dict[str, Any] = None,
+        legend_kwargs: dict[str, Any] = None,
+        tick_kwargs: dict[str, Any] = None,
+        label_kwargs: dict[str, Any] = None,
+        title_kwargs: dict[str, Any] = None,
+    ) -> tuple[plt.Figure, np.ndarray[plt.Axes]]:
+        """Plot simulation results of the compound groups as a grid.
+
+        Examples
+        --------
+        >>> plot_fluxes_grid([["v1", "v2"], ["v3", "v4]])
+        """
+        time = self.get_time()
+        fluxes = self.get_fluxes_df(normalise=normalise, concatenated=True)
+        plot_groups = [
+            (
+                time,
+                fluxes.loc[:, group].values,
+            )
+            for group in rate_groups
+        ]
+        return plot_grid(
+            plot_groups=plot_groups,
+            legend_groups=rate_groups,
+            ncols=ncols,
+            sharex=sharex,
+            sharey=sharey,
+            xlabels=xlabels,
+            ylabels=ylabels,
+            figure_title=figure_title,
+            plot_titles=plot_titles,
+            grid=grid,
+            tight_layout=tight_layout,
+            ax=ax,
+            figure_kwargs=figure_kwargs,
+            subplot_kwargs=subplot_kwargs,
+            plot_kwargs=plot_kwargs,
+            grid_kwargs=grid_kwargs,
+            legend_kwargs=legend_kwargs,
+            tick_kwargs=tick_kwargs,
+            label_kwargs=label_kwargs,
+            title_kwargs=title_kwargs,
+        )
+
     def plot_fluxes_against_variable(
         self,
         variable: str,
