@@ -1,16 +1,15 @@
-# Standard Library
+from __future__ import annotations
+
 import copy
 import math
 import re
 import warnings
 from collections import defaultdict
 
-# Third party
 import libsbml
 import numpy as np
 import sympy
 
-# Local code
 from ..ode import Model
 from .data import (
     AlgebraicRule,
@@ -919,7 +918,7 @@ class Parser:
             res = func(*[possible_sources[k] for k in assignment.function_args])
             if isinstance(res, (list, np.ndarray)):
                 res = res[0]
-            if par_name not in model.compounds and par_name not in model.derived_compounds:
+            if par_name not in model.compounds and par_name not in model.get_derived_compounds():
                 raise NotImplementedError("Initial assignment targeting unknown type")
             y0[par_name] = res
         return model, y0
