@@ -1,12 +1,19 @@
-# Standard Library
 import unittest
+import pytest
 
-# Third party
 import numpy as np
 from modelbase.ode import Model
 from modelbase.ode import ratelaws as rl
 
 
+
+def test_str(multiline_comparison):
+    model = Model()
+    model.add_compounds(("x", "y"))
+    model.add_stoichiometry("v1", {"x": -1, "y": 1})
+    multiline_comparison(("Model:","    2 Compounds","    1 Reactions"), str(model))
+
+
 class ModelBaseTests(unittest.TestCase):
     def test_init_empty(self):
         model = Model()
@@ -29,12 +36,6 @@ class ModelBaseTests(unittest.TestCase):
         m_copy = model.copy()
         self.assertIsNot(model, m_copy)
 
-    def test_str(self):
-        model = Model()
-        model.add_compounds(("x", "y"))
-        model.add_stoichiometry("v1", {"x": -1, "y": 1})
-        self.assertEqual(str(model), "Model:\n    2 Compounds\n    1 Reactions")
-
 
 class ReactionTests(unittest.TestCase):
     def test_add_reaction(self):
@@ -256,28 +257,28 @@ class ReactionTests(unittest.TestCase):
         self.assertEqual(rate["reversible"], True)
         self.assertEqual(model.stoichiometries["v1"], {"x2": -1, "y2": 1})
 
-    def test_update_reaction_meta_info(self):
-        parameters = {"k1": 1, "k2": 2}
-        model = Model(parameters=parameters)
-        model.add_compounds(["x", "y"])
-        model.add_reaction(
-            rate_name="v1",
-            function=lambda x, k: k * x,
-            stoichiometry={"x": -1, "y": 1},
-            modifiers=None,
-            parameters=["k1"],
-            reversible=False,
-        )
-        model.update_reaction("v1", **{"sbml_function": "k1 * x"})
-        rate = model.rates["v1"]
-        self.assertEqual(rate["function"].__name__, "v1")
-        self.assertEqual(rate["parameters"], ["k1"])
-        self.assertEqual(rate["substrates"], ["x"])
-        self.assertEqual(rate["products"], ["y"])
-        self.assertEqual(rate["modifiers"], [])
-        self.assertEqual(rate["dynamic_variables"], ["x"])
-        self.assertEqual(rate["reversible"], False)
-        self.assertEqual(model.meta_info["rates"]["v1"].sbml_function, "k1 * x")
+    # def test_update_reaction_meta_info(self):
+    #     parameters = {"k1": 1, "k2": 2}
+    #     model = Model(parameters=parameters)
+    #     model.add_compounds(["x", "y"])
+    #     model.add_reaction(
+    #         rate_name="v1",
+    #         function=lambda x, k: k * x,
+    #         stoichiometry={"x": -1, "y": 1},
+    #         modifiers=None,
+    #         parameters=["k1"],
+    #         reversible=False,
+    #     )
+    #     model.update_reaction("v1", **{"sbml_function": "k1 * x"})
+    #     rate = model.rates["v1"]
+    #     self.assertEqual(rate["function"].__name__, "v1")
+    #     self.assertEqual(rate["parameters"], ["k1"])
+    #     self.assertEqual(rate["substrates"], ["x"])
+    #     self.assertEqual(rate["products"], ["y"])
+    #     self.assertEqual(rate["modifiers"], [])
+    #     self.assertEqual(rate["dynamic_variables"], ["x"])
+    #     self.assertEqual(rate["reversible"], False)
+    #     self.assertEqual(model.meta_info["rates"]["v1"].sbml_function, "k1 * x")
 
     def test_remove_reaction(self):
         parameters = {"k": 1}
@@ -1155,281 +1156,6 @@ class ModelConversionTests(unittest.TestCase):
             self.assertEqual(lm.stoichiometries, {"v1__0": {"X__0": -1, "Y__0": 1}})
 
 
-class SourceCodeTests(unittest.TestCase):
-    def test_generate_source_code(self):
-        def module(x, y):
-            return [x / y]  # pragma: no cover
-
-        def rate(s, z, k_fwd):
-            return k_fwd * s / z  # pragma: no cover
-
-        model = Model()
-        model.add_parameters({"k1": 1, "p1": 1}, meta_info={"k1": {"unit": "mM"}})
-        model.add_compounds(compounds=("x", "y", "z"), meta_info={"x": {"common_name": "cpd1"}})
-        model.add_algebraic_module(
-            module_name="mod1",
-            function=module,
-            compounds=["x", "y"],
-            derived_compounds=["A1"],
-            modifiers=["z"],
-            parameters=["p1"],
-            **{"common_name": "a module"},
-        )
-        model.add_algebraic_module(
-            module_name="mod2",
-            function=module,
-            compounds=["x", "y"],
-            derived_compounds=["A2"],
-            modifiers=["z"],
-            parameters=["p1"],
-        )
-        model.add_rate(
-            rate_name="v1",
-            function=rate,
-            substrates=["x"],
-            products=["y"],
-            modifiers=["z"],
-            parameters=["k1"],
-            **{"common_name": "a rate"},
-        )
-        model.add_rate(
-            rate_name="v2",
-            function=rate,
-            substrates=["x"],
-            products=["y"],
-            modifiers=["z"],
-            parameters=["k1"],
-        )
-        model.add_stoichiometry(rate_name="v1", stoichiometry={"x": -1, "y": 1})
-
-        self.assertEqual(
-            model.generate_model_source_code(linted=False, include_meta_info=False).strip().split("\n"),
-            [
-                "import math",
-                "import numpy as np",
-                "from modelbase.ode import Model, Simulator",
-                "",
-                "def module(x, y):",
-                "    return [x / y]  # pragma: no cover",
-                "def rate(s, z, k_fwd):",
-                "    return k_fwd * s / z  # pragma: no cover",
-                "m = Model()",
-                "m.add_parameters(parameters={'k1': 1, 'p1': 1})",
-                "m.add_compounds(compounds=['x', 'y', 'z'])",
-                "m.add_algebraic_module(",
-                "    module_name='mod1',",
-                "    function=module,",
-                "    compounds=['x', 'y'],",
-                "    derived_compounds=['A1'],",
-                "    modifiers=['z'],",
-                "    parameters=['p1'],",
-                ")",
-                "m.add_algebraic_module(",
-                "    module_name='mod2',",
-                "    function=module,",
-                "    compounds=['x', 'y'],",
-                "    derived_compounds=['A2'],",
-                "    modifiers=['z'],",
-                "    parameters=['p1'],",
-                ")",
-                "m.add_rate(",
-                "    rate_name='v1',",
-                "    function=rate,",
-                "    substrates=['x'],",
-                "    products=['y'],",
-                "    modifiers=['z'],",
-                "    parameters=['k1'],",
-                "    reversible=False,",
-                ")",
-                "m.add_rate(",
-                "    rate_name='v2',",
-                "    function=rate,",
-                "    substrates=['x'],",
-                "    products=['y'],",
-                "    modifiers=['z'],",
-                "    parameters=['k1'],",
-                "    reversible=False,",
-                ")",
-                "m.add_stoichiometries(rate_stoichiometries={'v1': {'x': -1, 'y': 1}})",
-            ],
-        )
-
-        self.assertEqual(
-            model.generate_model_source_code(linted=False, include_meta_info=True).strip().split("\n"),
-            [
-                "import math",
-                "import numpy as np",
-                "from modelbase.ode import Model, Simulator",
-                "",
-                "def module(x, y):",
-                "    return [x / y]  # pragma: no cover",
-                "def rate(s, z, k_fwd):",
-                "    return k_fwd * s / z  # pragma: no cover",
-                "m = Model()",
-                "m.add_parameters(parameters={'k1': 1, 'p1': 1}, meta_info={'k1': {'unit': 'mM'}})",
-                "m.add_compounds(compounds=['x', 'y', 'z'], meta_info={'x': {'common_name': 'cpd1', 'compartment': 'c'}, 'y': {'compartment': 'c'}, 'z': {'compartment': 'c'}})",
-                "m.add_algebraic_module(",
-                "    module_name='mod1',",
-                "    function=module,",
-                "    compounds=['x', 'y'],",
-                "    derived_compounds=['A1'],",
-                "    modifiers=['z'],",
-                "    parameters=['p1'],",
-                "**{'common_name': 'a module'})",
-                "m.add_algebraic_module(",
-                "    module_name='mod2',",
-                "    function=module,",
-                "    compounds=['x', 'y'],",
-                "    derived_compounds=['A2'],",
-                "    modifiers=['z'],",
-                "    parameters=['p1'],",
-                ")",
-                "m.add_rate(",
-                "    rate_name='v1',",
-                "    function=rate,",
-                "    substrates=['x'],",
-                "    products=['y'],",
-                "    modifiers=['z'],",
-                "    parameters=['k1'],",
-                "    reversible=False,",
-                "    **{'common_name': 'a rate'}",
-                ")",
-                "m.add_rate(",
-                "    rate_name='v2',",
-                "    function=rate,",
-                "    substrates=['x'],",
-                "    products=['y'],",
-                "    modifiers=['z'],",
-                "    parameters=['k1'],",
-                "    reversible=False,",
-                ")",
-                "m.add_stoichiometries(rate_stoichiometries={'v1': {'x': -1, 'y': 1}})",
-            ],
-        )
-
-        self.assertEqual(
-            model.generate_model_source_code(linted=True, include_meta_info=False).strip().split("\n"),
-            [
-                "import math",
-                "import numpy as np",
-                "from modelbase.ode import Model, Simulator",
-                "",
-                "",
-                "def module(x, y):",
-                "    return [x / y]  # pragma: no cover",
-                "",
-                "",
-                "def rate(s, z, k_fwd):",
-                "    return k_fwd * s / z  # pragma: no cover",
-                "",
-                "",
-                "m = Model()",
-                'm.add_parameters(parameters={"k1": 1, "p1": 1})',
-                'm.add_compounds(compounds=["x", "y", "z"])',
-                "m.add_algebraic_module(",
-                '    module_name="mod1",',
-                "    function=module,",
-                '    compounds=["x", "y"],',
-                '    derived_compounds=["A1"],',
-                '    modifiers=["z"],',
-                '    parameters=["p1"],',
-                ")",
-                "m.add_algebraic_module(",
-                '    module_name="mod2",',
-                "    function=module,",
-                '    compounds=["x", "y"],',
-                '    derived_compounds=["A2"],',
-                '    modifiers=["z"],',
-                '    parameters=["p1"],',
-                ")",
-                "m.add_rate(",
-                '    rate_name="v1",',
-                "    function=rate,",
-                '    substrates=["x"],',
-                '    products=["y"],',
-                '    modifiers=["z"],',
-                '    parameters=["k1"],',
-                "    reversible=False,",
-                ")",
-                "m.add_rate(",
-                '    rate_name="v2",',
-                "    function=rate,",
-                '    substrates=["x"],',
-                '    products=["y"],',
-                '    modifiers=["z"],',
-                '    parameters=["k1"],',
-                "    reversible=False,",
-                ")",
-                'm.add_stoichiometries(rate_stoichiometries={"v1": {"x": -1, "y": 1}})',
-            ],
-        )
-        self.assertEqual(
-            model.generate_model_source_code(linted=True, include_meta_info=True).strip().split("\n"),
-            [
-                "import math",
-                "import numpy as np",
-                "from modelbase.ode import Model, Simulator",
-                "",
-                "",
-                "def module(x, y):",
-                "    return [x / y]  # pragma: no cover",
-                "",
-                "",
-                "def rate(s, z, k_fwd):",
-                "    return k_fwd * s / z  # pragma: no cover",
-                "",
-                "",
-                "m = Model()",
-                'm.add_parameters(parameters={"k1": 1, "p1": 1}, meta_info={"k1": {"unit": "mM"}})',
-                "m.add_compounds(",
-                '    compounds=["x", "y", "z"],',
-                "    meta_info={",
-                '        "x": {"common_name": "cpd1", "compartment": "c"},',
-                '        "y": {"compartment": "c"},',
-                '        "z": {"compartment": "c"},',
-                "    },",
-                ")",
-                "m.add_algebraic_module(",
-                '    module_name="mod1",',
-                "    function=module,",
-                '    compounds=["x", "y"],',
-                '    derived_compounds=["A1"],',
-                '    modifiers=["z"],',
-                '    parameters=["p1"],',
-                '    **{"common_name": "a module"}',
-                ")",
-                "m.add_algebraic_module(",
-                '    module_name="mod2",',
-                "    function=module,",
-                '    compounds=["x", "y"],',
-                '    derived_compounds=["A2"],',
-                '    modifiers=["z"],',
-                '    parameters=["p1"],',
-                ")",
-                "m.add_rate(",
-                '    rate_name="v1",',
-                "    function=rate,",
-                '    substrates=["x"],',
-                '    products=["y"],',
-                '    modifiers=["z"],',
-                '    parameters=["k1"],',
-                "    reversible=False,",
-                '    **{"common_name": "a rate"}',
-                ")",
-                "m.add_rate(",
-                '    rate_name="v2",',
-                "    function=rate,",
-                '    substrates=["x"],',
-                '    products=["y"],',
-                '    modifiers=["z"],',
-                '    parameters=["k1"],',
-                "    reversible=False,",
-                ")",
-                'm.add_stoichiometries(rate_stoichiometries={"v1": {"x": -1, "y": 1}})',
-            ],
-        )
-
-
 class SBMLTests(unittest.TestCase):
     def test_create_sbml_rates_without_function(self):
         model = Model()
