@@ -1,7 +1,6 @@
-# Standard Library
+
 import unittest
 
-# Third party
 import numpy as np
 from modelbase.ode import Model, Simulator
 from modelbase.ode import ratefunctions as rf
@@ -368,7 +367,9 @@ class SimulationTests(unittest.TestCase):
         self.assertEqual(list(df.index), [0.0, 1.0, 2.0])
         np.testing.assert_array_almost_equal(df.values, [[0.0], [1.0], [1.5]])
         #
-        np.testing.assert_array_almost_equal(s.get_full_results_array(), np.array([[0.0, 1.0], [1.0, 1.0], [1.5, 0.5]]))
+        np.testing.assert_array_almost_equal(
+            s.get_full_results_array(), np.array([[0.0, 1.0], [1.0, 1.0], [1.5, 0.5]])
+        )
         #
         d = s.get_full_results_dict()
         self.assertEqual(list(d.keys()), ["x", "A"])
@@ -423,13 +424,21 @@ class SimulationTests(unittest.TestCase):
 
         # dict
         np.testing.assert_array_equal((y / 2).flatten(), s.get_results_dict(normalise=2)["x"])
-        np.testing.assert_array_equal((y / 2).flatten(), s.get_results_dict(normalise=np.ones(len(y)) * 2)["x"])
-        np.testing.assert_array_equal((y / 2).flatten(), s.get_results_dict(normalise=[np.ones(len(y)) * 2])["x"])
+        np.testing.assert_array_equal(
+            (y / 2).flatten(), s.get_results_dict(normalise=np.ones(len(y)) * 2)["x"]
+        )
+        np.testing.assert_array_equal(
+            (y / 2).flatten(), s.get_results_dict(normalise=[np.ones(len(y)) * 2])["x"]
+        )
 
         # dict
         np.testing.assert_array_equal((y / 2).flatten(), s.get_results_dict(normalise=2)["x"])
-        np.testing.assert_array_equal((y / 2).flatten(), s.get_results_dict(normalise=np.ones(len(y)) * 2)["x"])
-        np.testing.assert_array_equal((y / 2).flatten(), s.get_results_dict(normalise=[np.ones(len(y)) * 2])["x"])
+        np.testing.assert_array_equal(
+            (y / 2).flatten(), s.get_results_dict(normalise=np.ones(len(y)) * 2)["x"]
+        )
+        np.testing.assert_array_equal(
+            (y / 2).flatten(), s.get_results_dict(normalise=[np.ones(len(y)) * 2])["x"]
+        )
 
         # full dict
         np.testing.assert_array_equal((y / 2).flatten(), s.get_full_results_dict(normalise=2)["x"])
@@ -445,11 +454,15 @@ class SimulationTests(unittest.TestCase):
         # df
         np.testing.assert_array_equal((y / 2).flatten(), s.get_results_df(normalise=2)["x"])
         np.testing.assert_array_equal((y / 2).flatten(), s.get_results_df(normalise=np.ones(len(y)) * 2)["x"])
-        np.testing.assert_array_equal((y / 2).flatten(), s.get_results_df(normalise=[np.ones(len(y)) * 2])["x"])
+        np.testing.assert_array_equal(
+            (y / 2).flatten(), s.get_results_df(normalise=[np.ones(len(y)) * 2])["x"]
+        )
 
         # full df
         np.testing.assert_array_equal((y / 2).flatten(), s.get_full_results_df(normalise=2)["x"])
-        np.testing.assert_array_equal((y / 2).flatten(), s.get_full_results_df(normalise=np.ones(len(y)) * 2)["x"])
+        np.testing.assert_array_equal(
+            (y / 2).flatten(), s.get_full_results_df(normalise=np.ones(len(y)) * 2)["x"]
+        )
         np.testing.assert_array_equal(
             (y / 2).flatten(),
             s.get_full_results_df(normalise=[np.ones(len(y)) * 2])["x"],
@@ -469,7 +482,9 @@ class SimulationTests(unittest.TestCase):
         # variables
         np.testing.assert_array_equal(y / 2, s.get_variables(variables=["x"], normalise=2))
         np.testing.assert_array_equal(y / 2, s.get_variables(variables=["x"], normalise=np.ones(len(y)) * 2))
-        np.testing.assert_array_equal(y / 2, s.get_variables(variables=["x"], normalise=[np.ones(len(y)) * 2]))
+        np.testing.assert_array_equal(
+            y / 2, s.get_variables(variables=["x"], normalise=[np.ones(len(y)) * 2])
+        )
 
         # fluxes array
         np.testing.assert_array_equal(y / 2, s.get_fluxes_array(normalise=2))
@@ -478,10 +493,16 @@ class SimulationTests(unittest.TestCase):
 
         # fluxes dict
         np.testing.assert_array_equal((y / 2).flatten(), s.get_fluxes_dict(normalise=2)["v1"])
-        np.testing.assert_array_equal((y / 2).flatten(), s.get_fluxes_dict(normalise=np.ones(len(y)) * 2)["v1"])
-        np.testing.assert_array_equal((y / 2).flatten(), s.get_fluxes_dict(normalise=[np.ones(len(y)) * 2])["v1"])
+        np.testing.assert_array_equal(
+            (y / 2).flatten(), s.get_fluxes_dict(normalise=np.ones(len(y)) * 2)["v1"]
+        )
+        np.testing.assert_array_equal(
+            (y / 2).flatten(), s.get_fluxes_dict(normalise=[np.ones(len(y)) * 2])["v1"]
+        )
 
         # fluxes df
         np.testing.assert_array_equal((y / 2).flatten(), s.get_fluxes_df(normalise=2)["v1"])
         np.testing.assert_array_equal((y / 2).flatten(), s.get_fluxes_df(normalise=np.ones(len(y)) * 2)["v1"])
-        np.testing.assert_array_equal((y / 2).flatten(), s.get_fluxes_df(normalise=[np.ones(len(y)) * 2])["v1"])
+        np.testing.assert_array_equal(
+            (y / 2).flatten(), s.get_fluxes_df(normalise=[np.ones(len(y)) * 2])["v1"]
+        )
