@@ -1,8 +1,7 @@
-# Standard Library
+
 import unittest
 from math import factorial
 
-# Third party
 from modelbase.ode import ratefunctions as rf
 
 
@@ -264,27 +263,35 @@ class RateFunctionTests(unittest.TestCase):
 
     def test_reversible_uncompetitive_inhibition(self):
         self.assertEqual(
-            rf.reversible_uncompetitive_inhibition(S=1, P=0.5, I=0.5, vmax_fwd=2, vmax_bwd=1, kms=1, kmp=1, ki=0.7),
+            rf.reversible_uncompetitive_inhibition(
+                S=1, P=0.5, I=0.5, vmax_fwd=2, vmax_bwd=1, kms=1, kmp=1, ki=0.7
+            ),
             0.525,
         )
 
     def test_reversible_noncompetitive_inhibition(self):
         self.assertEqual(
-            rf.reversible_noncompetitive_inhibition(S=1, P=0.5, I=0.5, vmax_fwd=2, vmax_bwd=1, kms=1, kmp=1, ki=1),
+            rf.reversible_noncompetitive_inhibition(
+                S=1, P=0.5, I=0.5, vmax_fwd=2, vmax_bwd=1, kms=1, kmp=1, ki=1
+            ),
             0.4,
         )
 
     def test_reversible_uncompetitive_inhibition_keq(self):
 
         self.assertEqual(
-            rf.reversible_uncompetitive_inhibition_keq(S=1, P=0.5, I=0.5, vmax_fwd=1, kms=1, kmp=1, ki=0.7, keq=1),
+            rf.reversible_uncompetitive_inhibition_keq(
+                S=1, P=0.5, I=0.5, vmax_fwd=1, kms=1, kmp=1, ki=0.7, keq=1
+            ),
             0.175,
         )
 
     def test_reversible_noncompetitive_inhibition_keq(self):
 
         self.assertEqual(
-            rf.reversible_noncompetitive_inhibition_keq(S=1, P=0.5, I=0.5, vmax_fwd=2, kms=1, kmp=1, ki=0.5, keq=1),
+            rf.reversible_noncompetitive_inhibition_keq(
+                S=1, P=0.5, I=0.5, vmax_fwd=2, kms=1, kmp=1, ki=0.5, keq=1
+            ),
             0.2,
         )
 
